/******************************************************************************
  @header BDBDatabaseEntryNumber
 
  @availability OS X, GNUstep
  @copyright (C) 2004, 2005, 2006 Oliver Langer
 
  Author: Oliver Langer

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

  <pre>
  -------------------------------------------------------------------------
  Modification history

  09.01.2005 ola     initial version
  22.08.2006 ola     license changed
  -------------------------------------------------------------------------
  </pre>
******************************************************************************/


#if !defined(__BDBDATABASERECORDNUMBER_H)
#define __BDBDATABASERECORDNUMBER_H

#include <BDB/BDBDatabaseEntryData.h>

/*!
 * @class BDBDatabaseRecordNumber
 * @discuss instances of this class represent record numbers of entries.
 */
@interface BDBDatabaseRecordNumber : BDBDatabaseEntryData {
@private
  u_int32_t entryNumber;
}


/*!
 * @method init
 * @result self
 * @abstract initializes the receiver with an unknown entry number
 */
- init;


/*!
 * @method initWithEntryNumber 
 * @abstract create an instance representing the specified entry number
 * @param aNumber an entry number
 * @result self
 */
- initWithEntryNumber: (u_int32_t) aNumber;


/*!
 * @method entryNumber
 * @result the entry number represented by the receiver
 */
- (u_int32_t) entryNumber;


/*!
 * @method setEntryNumber
 * @abstract specify the number of the entry
 * @param aNumber entry's number
 * @result self
 */
- setEntryNumber: (u_int32_t) aNumber;
@end

#endif
